@@ -1,8 +1,16 @@
+"""Main package for humanize."""
 import pkg_resources
+
 from humanize.filesize import naturalsize
-from humanize.i18n import activate, deactivate
-from humanize.number import apnumber, fractional, intcomma, intword, ordinal
-from humanize.time import naturaldate, naturalday, naturaldelta, naturaltime
+from humanize.i18n import activate, deactivate, thousands_separator
+from humanize.number import apnumber, fractional, intcomma, intword, ordinal, scientific
+from humanize.time import (
+    naturaldate,
+    naturalday,
+    naturaldelta,
+    naturaltime,
+    precisedelta,
+)
 
 __version__ = VERSION = pkg_resources.get_distribution(__name__).version
 
@@ -21,5 +29,8 @@ __all__ = [
     "naturalsize",
     "naturaltime",
     "ordinal",
+    "precisedelta",
+    "scientific",
+    "thousands_separator",
     "VERSION",
 ]
