@@ -8,12 +8,44 @@ from fractions import Fraction
 from .i18n import gettext as _
 from .i18n import gettext_noop as N_
 from .i18n import pgettext as P_
+from .i18n import thousands_separator
 
 
 def ordinal(value):
-    """Converts an integer to its ordinal as a string. 1 is '1st', 2 is '2nd',
-    3 is '3rd', etc. Works for any integer or anything int() will turn into an
-    integer.  Anything other value will have nothing done to it."""
+    """Converts an integer to its ordinal as a string.
+
+    For example, 1 is "1st", 2 is "2nd", 3 is "3rd", etc. Works for any integer or
+    anything `int()` will turn into an integer. Anything other value will have nothing
+    done to it.
+
+    Examples:
+        ```pycon
+        >>> ordinal(1)
+        '1st'
+        >>> ordinal(1002)
+        '1002nd'
+        >>> ordinal(103)
+        '103rd'
+        >>> ordinal(4)
+        '4th'
+        >>> ordinal(12)
+        '12th'
+        >>> ordinal(101)
+        '101st'
+        >>> ordinal(111)
+        '111th'
+        >>> ordinal("something else")
+        'something else'
+        >>> ordinal(None) is None
+        True
+
+        ```
+    Args:
+        value (int, str, float): Integer to convert.
+
+    Returns:
+        str: Ordinal string.
+    """
     try:
         value = int(value)
     except (TypeError, ValueError):
@@ -31,26 +63,45 @@ def ordinal(value):
         P_("9", "th"),
     )
     if value % 100 in (11, 12, 13):  # special case
-        return "%d%s" % (value, t[0])
-    return "%d%s" % (value, t[value % 10])
+        return f"{value}{t[0]}"
+    return f"{value}{t[value % 10]}"
 
 
 def intcomma(value, ndigits=None):
     """Converts an integer to a string containing commas every three digits.
 
     For example, 3000 becomes "3,000" and 45000 becomes "45,000". To maintain some
-    compatibility with Django's intcomma, this function also accepts floats.
+    compatibility with Django's `intcomma`, this function also accepts floats.
 
+    Examples:
+        ``pycon
+        >>> intcomma(100)
+        '100'
+        >>> intcomma("1000")
+        '1,000'
+        >>> intcomma(1_000_000)
+        '1,000,000'
+        >>> intcomma(1_234_567.25)
+        '1,234,567.25'
+        >>> intcomma(1234.5454545, 2)
+        '1,234.55'
+        >>> intcomma(14308.40, 1)
+        '14,308.4'
+        >>> intcomma(None) is None
+        True
+
+        ```
     Args:
-        value (int, float, string): Integer or float to convert.
-        ndigits (int, None): digits of precision for rounding after the decimal point.
+        value (int, float, str): Integer or float to convert.
+        ndigits (int, None): Digits of precision for rounding after the decimal point.
 
     Returns:
         str: string containing commas every three digits.
     """
+    sep = thousands_separator()
     try:
         if isinstance(value, str):
-            float(value.replace(",", ""))
+            float(value.replace(sep, ""))
         else:
             float(value)
     except (TypeError, ValueError):
@@ -61,7 +112,7 @@ def intcomma(value, ndigits=None):
     else:
         orig = str(value)
 
-    new = re.sub(r"^(-?\d+)(\d{3})", r"\g<1>,\g<2>", orig)
+    new = re.sub(r"^(-?\d+)(\d{3})", fr"\g<1>{sep}\g<2>", orig)
     if orig == new:
         return new
     else:
@@ -87,18 +138,34 @@ human_powers = (
 def intword(value, format="%.1f"):
     """Converts a large integer to a friendly text representation.
 
-    Works best for numbers over 1 million. For example, 1000000 becomes "1.0 million",
-    1200000 becomes "1.2 million" and "1200000000" becomes "1.2 billion". Supports up to
-    decillion (33 digits) and googol (100 digits).
+    Works best for numbers over 1 million. For example, 1_000_000 becomes "1.0 million",
+    1200000 becomes "1.2 million" and "1_200_000_000" becomes "1.2 billion". Supports up
+    to decillion (33 digits) and googol (100 digits).
 
+    Examples:
+        ```pycon
+        >>> intword("100")
+        '100'
+        >>> intword("1000000")
+        '1.0 million'
+        >>> intword(1_200_000_000)
+        '1.2 billion'
+        >>> intword(8100000000000000000000000000000000)
+        '8.1 decillion'
+        >>> intword(None) is None
+        True
+        >>> intword("1234000", "%0.3f")
+        '1.234 million'
+
+        ```
     Args:
-        value (int, float, string): Integer to convert.
-        format (str): to change the number of decimal or general format of the number
+        value (int, float, str): Integer to convert.
+        format (str): To change the number of decimal or general format of the number
             portion.
 
     Returns:
-        str: friendly text representation as a string, unless the value passed could not
-        be coaxed into an int.
+        str: Friendly text representation as a string, unless the value passed could not
+        be coaxed into an `int`.
     """
     try:
         value = int(value)
@@ -121,12 +188,28 @@ def intword(value, format="%.1f"):
 def apnumber(value):
     """Converts an integer to Associated Press style.
 
+    Examples:
+      ```pycon
+      >>> apnumber(0)
+      'zero'
+      >>> apnumber(5)
+      'five'
+      >>> apnumber(10)
+      '10'
+      >>> apnumber("7")
+      'seven'
+      >>> apnumber("foo")
+      'foo'
+      >>> apnumber(None) is None
+      True
+
+      ```
     Args:
-        value (int, float, string): Integer to convert.
+        value (int, float, str): Integer to convert.
 
     Returns:
         str: For numbers 0-9, the number spelled out. Otherwise, the number. This always
-        returns a string unless the value was not int-able, unlike the Django filter.
+        returns a string unless the value was not `int`-able, unlike the Django filter.
     """
     try:
         value = int(value)
@@ -149,21 +232,41 @@ def apnumber(value):
 
 
 def fractional(value):
-    """
-    There will be some cases where one might not want to show
-        ugly decimal places for floats and decimals.
-    This function returns a human readable fractional number
-        in form of fractions and mixed fractions.
-    Pass in a string, or a number or a float, and this function returns
-        a string representation of a fraction
-        or whole number
-        or a mixed fraction
+    """Convert to fractional number.
+
+    There will be some cases where one might not want to show ugly decimal places for
+    floats and decimals.
+
+    This function returns a human-readable fractional number in form of fractions and
+    mixed fractions.
+
+    Pass in a string, or a number or a float, and this function returns:
+
+    * a string representation of a fraction
+    * or a whole number
+    * or a mixed fraction
+
     Examples:
-        fractional(0.3) will return '1/3'
-        fractional(1.3) will return '1 3/10'
-        fractional(float(1/3)) will return '1/3'
-        fractional(1) will return '1'
-    This will always return a string.
+        ```pycon
+        >>> fractional(0.3)
+        '3/10'
+        >>> fractional(1.3)
+        '1 3/10'
+        >>> fractional(float(1/3))
+        '1/3'
+        >>> fractional(1)
+        '1'
+        >>> fractional("ten")
+        'ten'
+        >>> fractional(None) is None
+        True
+
+        ```
+    Args:
+        value (int, float, str): Integer to convert.
+
+    Returns:
+        str: Fractional number as a string.
     """
     try:
         number = float(value)
@@ -176,27 +279,43 @@ def fractional(value):
     if whole_number and not numerator and denominator == 1:
         # this means that an integer was passed in
         # (or variants of that integer like 1.0000)
-        return "%.0f" % whole_number
+        return f"{whole_number:.0f}"
     elif not whole_number:
-        return "{:.0f}/{:.0f}".format(numerator, denominator)
+        return f"{numerator:.0f}/{denominator:.0f}"
     else:
-        return "{:.0f} {:.0f}/{:.0f}".format(whole_number, numerator, denominator)
+        return f"{whole_number:.0f} {numerator:.0f}/{denominator:.0f}"
 
 
 def scientific(value, precision=2):
     """Return number in string scientific notation z.wq x 10ⁿ.
 
     Examples:
-        float(0.3) will return "3.00 x 10⁻¹"
-        int(500) will return "5.00 x 10²"
-    This will always return a string.
+        ```pycon
+        >>> scientific(float(0.3))
+        '3.00 x 10⁻¹'
+        >>> scientific(int(500))
+        '5.00 x 10²'
+        >>> scientific(-1000)
+        '1.00 x 10⁻³'
+        >>> scientific(1000, 1)
+        '1.0 x 10³'
+        >>> scientific(1000, 3)
+        '1.000 x 10³'
+        >>> scientific("99")
+        '9.90 x 10¹'
+        >>> scientific("foo")
+        'foo'
+        >>> scientific(None) is None
+        True
+
+        ```
 
     Args:
-        value (int, float, string): Input number.
+        value (int, float, str): Input number.
         precision (int): Number of decimal for first part of the number.
 
     Returns:
-        str: number in scientific notation z.wq x 10ⁿ.
+        str: Number in scientific notation z.wq x 10ⁿ.
     """
     exponents = {
         "0": "⁰",
