@@ -2,8 +2,9 @@
 
 """Number tests."""
 
-import humanize
 import pytest
+
+import humanize
 from humanize import number
 
 
@@ -36,8 +37,8 @@ def test_ordinal(test_input, expected):
         ([1000], "1,000"),
         ([10123], "10,123"),
         ([10311], "10,311"),
-        ([1000000], "1,000,000"),
-        ([1234567.25], "1,234,567.25"),
+        ([1_000_000], "1,000,000"),
+        ([1_234_567.25], "1,234,567.25"),
         (["100"], "100"),
         (["1000"], "1,000"),
         (["10123"], "10,123"),
